==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColumnPinnedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnPinnedChangedEventArgsDescription } from "./ColumnPinnedChangedEventArgsDescription";
/**
 * @hidden
 */
export let ColumnPinnedChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnPinnedChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnPinnedChangedEventArgsDescriptionMetadata.a == null) {
                ColumnPinnedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnPinnedChangedEventArgsDescriptionMetadata.c(ColumnPinnedChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(ColumnPinnedChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnPinnedChangedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("Pinned", "ExportedType:string:PinnedPositions");
            a.item("Pinned@names", "None;Left;Right");
        }
        static d(a) {
            ColumnPinnedChangedEventArgsDescriptionMetadata.b(a);
            a.aa("ColumnPinnedChangedEventArgs", () => new ColumnPinnedChangedEventArgsDescription());
            a.z("ColumnPinnedChangedEventArgs", ColumnPinnedChangedEventArgsDescriptionMetadata.a);
        }
    }
    ColumnPinnedChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnPinnedChangedEventArgsDescriptionMetadata, 'ColumnPinnedChangedEventArgsDescriptionMetadata');
    ColumnPinnedChangedEventArgsDescriptionMetadata.a = null;
    return ColumnPinnedChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnPinnedChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { ColumnPinnedChangedEventArgsDescription } from "./ColumnPinnedChangedEventArgsDescription";
/**
 * @hidden
 */
export let ColumnPinnedChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnPinnedChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnPinnedChangedEventArgsDescriptionMetadata.a == null) {
                ColumnPinnedChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnPinnedChangedEventArgsDescriptionMetadata.c(ColumnPinnedChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(ColumnPinnedChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnPinnedChangedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("Pinned", "ExportedType:string:PinnedPositions");
            a.item("Pinned@names", "None;Left;Right");
        }
        static d(a) {
            ColumnPinnedChangedEventArgsDescriptionMetadata.b(a);
            a.ac("ColumnPinnedChangedEventArgs", () => new ColumnPinnedChangedEventArgsDescription());
            a.ab("ColumnPinnedChangedEventArgs", ColumnPinnedChangedEventArgsDescriptionMetadata.a);
        }
    }
    ColumnPinnedChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnPinnedChangedEventArgsDescriptionMetadata, 'ColumnPinnedChangedEventArgsDescriptionMetadata');
    ColumnPinnedChangedEventArgsDescriptionMetadata.a = null;
    return ColumnPinnedChangedEventArgsDescriptionMetadata;
})();
